OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactes",
    "Download" : "Baixa",
    "Copy link" : "Copiar enllaç",
    "Click to copy the link to your clipboard" : "Feu clic per copiar l'enllaç al porta-retalls",
    "Toggle sharing" : "Canviar compartició",
    "Delete" : "Suprimeix",
    "Rename" : "Renombra",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "can edit" : "pot editar",
    "Close" : "Tanca",
    "Copied!" : "Copiat!",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Prem ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Prem Ctrl-C per copiar.",
    "Address book name" : "Nom de la llibreta d'adreces",
    "Only these special characters are allowed: -_.!?#|()" : "Només es permeten aquests caràcters especials: -_.!? # | ()",
    "Address book could not be created." : "No s'ha pogut crear la llibreta d'adreces.",
    "The selected image is too big (max 1MB)" : "La imatge seleccionada és massa gran (màxim 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Aquesta targeta estava corrompuda i s'ha arreglat. Comprova la informació i guarda-la per fer els canvis permanents.",
    "No contacts in here" : "No hi ha contactes",
    "Name" : "Nom",
    "Organization" : "Organització",
    "Title" : "Títol",
    "Add field …" : "Afegeix un camp ...",
    "Save changes" : "Desa els canvis",
    "Address book" : "Llibreta d'adreces",
    "Loading contacts …" : "S'estan carregant contactes ...",
    "Import into" : "Importa a",
    "Importing..." : "Important...",
    "Select your addressbook" : "Escull la teva llibreta d'adreces",
    "No search result for {query}" : "No s'han trobat resultats per {query}",
    "All contacts" : "Tots els contactes",
    "Post office box" : "Apartat de Correus",
    "Postal code" : "Codi postal",
    "City" : "Ciutat",
    "State or province" : "Estat o província",
    "Country" : "País",
    "Address" : "Adreça",
    "(new group)" : "(grup nou)",
    "Last name" : "Cognom",
    "First name" : "Nom",
    "Additional names" : "Noms addicionals",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "Importing into" : "Important a",
    "New contact" : "Contacte nou",
    "Not grouped" : "Sense grup",
    "Sort by" : "Ordena per",
    "{addressbook} shared by {owner}" : "{addressbook} compartida per {owner}",
    "Contact not found." : "No s'ha trobat el contacte",
    "Contact could not be created." : "No s'ha pogut crear el contacte.",
    "No contacts in file. Only vCard files are allowed." : "No hi ha contactes al fitxer. Només estan permesos fitxers vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Només compatible amb VCard versió 4.0 (RFC6350) o versió 3.0 (RFC2426).",
    "Contact could not be saved." : "No s'ha pogut desar el contacte.",
    "Display name" : "Nom mostrat",
    "Nickname" : "Sobrenom",
    "Detailed name" : "Nom detallat",
    "Notes" : "Anotacions",
    "Website" : "Pàgina web",
    "Federated Cloud ID" : "ID de núvol federat",
    "Home" : "Casa",
    "Work" : "Feina",
    "Other" : "Un altre",
    "Groups" : "Grups",
    "Birthday" : "Aniversari",
    "Anniversary" : "Aniversari",
    "Date of death" : "Data de la mort",
    "Email" : "Correu electrònic",
    "Instant messaging" : "Missatgeria instantània",
    "Phone" : "Telèfon",
    "Mobile" : "Mòbil",
    "Fax" : "Fax",
    "Fax home" : "Fax (casa)",
    "Fax work" : "Fax (feina)",
    "Pager" : "Paginador",
    "Voice" : "Veu",
    "Social network" : "Xarxa social",
    "Relationship" : "Relació",
    "Spouse" : "Parella",
    "Child" : "Fill",
    "Mother" : "Mare",
    "Father" : "Pare",
    "Parent" : "Pares",
    "Brother" : "Germà",
    "Sister" : "Germana",
    "Relative" : "Parent",
    "Friend" : "Amic",
    "Colleague" : "Company",
    "Manager" : "Gestor",
    "Assistant" : "Assistent",
    "Gender" : "Gènere",
    "Female" : "Femení",
    "Male" : "Masculí",
    "Details" : "Detalls",
    "Settings" : "Configuració"
},
"nplurals=2; plural=(n != 1);");
